
# seven_top

## 天志互联Python淘宝top库

### 1.0.5 更新内容
* 淘宝top库初始工程

### 1.0.8 更新内容
* 增加新的api

### 1.0.9 更新内容
* 增加新的api
CrmMemberIdentityGetRequest.py
CrmMemberJoinurlGetRequest.py

### 1.0.10 更新内容
* 增加新的api
MiniappCloudMongoInsertRequest.py
MiniappCloudMongoUpdateRequest.py

### 1.0.11 更新内容
* 增加新的api
AlibabaBenefitDrawRequest.py
AlibabaBenefitQueryRequest.py
AlibabaBenefitSendRequest.py
AlibabaBeneiftDrawRequest.py